@@ -8,13 +8,13 @@ function(X){
 #  gassign("nomData",nameJDD)
   assign("nomData",nameJDD, envir=G)
   if (!(inherits(X, "FAMDshiny") | inherits(X, "data.frame") | inherits(X, "FAMD"))){
-    stop('df is not a dataframe, the results of the FAMDshiny function or a FAMD result')
+    stop(gettext('df is not a dataframe, the results of the FAMDshiny function or a FAMD result'))
   }
   if(is.data.frame(X)==TRUE){
     quanti=names(which(sapply(X,is.numeric)))
     quali=names(which(!(sapply(X,is.numeric))))
     if(length(quanti)==0 || length(quali)==0)
-      stop('you data is not mixed')
+      stop(gettext('Your dataset is not mixed'))
   }
   a=shiny::runApp(system.file("FactoFAMDapp2", package="Factoshiny"),launch.browser = TRUE)
   return(invisible(a))
