@@ -36,23 +36,23 @@ if(inherits(x,"MFA")){
   ind2=TRUE
   ind3=TRUE
   ind4=TRUE
-  drawing="a"
+  drawing=gettext("group")
   drawing2=NULL
-  partial=1
+  partial=gettext("None")
   partial2=NULL
   partial3=FALSE
   selectvar="no"
   selectvar2=NULL
-  hide="non"
+  hide=gettext("Nothing")
   colorvar=TRUE
   freq1=TRUE
   freq2=TRUE
   partaxe=TRUE
-  title1="Groups representation"
-  title2="Individual factor map"
-  title3="Correlation circle"
-  title4="Partial axes"
-  title5="Frequencies"
+title1=gettext("Groups representation")
+title2=gettext("Individual factor map")
+title3=gettext("Correlation circle")
+title4=gettext("Graph of the partial axes")
+title5=gettext("Graph of the frequencies")
 }
 nameJDD=nomData
 nom=rownames(code$ind$coord)
@@ -66,4 +66,5 @@ nom=rownames(data)
 num=c(1:length(nom))
 QualiChoice=quali
 IdChoices=c(1:length(VariableChoices))
-Idqualisup=c(1:length(QualiChoice))
\ No newline at end of file
+Idqualisup=c(1:length(QualiChoice))
+nomData=unlist(strsplit(as.character(nomData),"\\["))[1]
\ No newline at end of file
